==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic.md <==
# AwsIoTGreengrassComponentPublic


```text
aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')
```



| Illustration | AwsIoTGreengrassComponentPublic | AwsIoTGreengrassComponentPublicCard | AwsIoTGreengrassComponentPublicGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic.png) | ![illustration for AwsIoTGreengrassComponentPublic](../../../aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic.Local.png) | ![illustration for AwsIoTGreengrassComponentPublicCard](../../../aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublicCard.Local.png) | ![illustration for AwsIoTGreengrassComponentPublicGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublicGroup.Local.png) |




## AwsIoTGreengrassComponentPublic

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublic
include('aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublic('AwsIoTGreengrassComponentPublic', 'Aws Io T Greengrass Component Public', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublic
include('aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublic('AwsIoTGreengrassComponentPublic', 'Aws Io T Greengrass Component Public', 'an optional tech label')
@enduml
```

## AwsIoTGreengrassComponentPublicCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicCard
include('aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicCard('AwsIoTGreengrassComponentPublicCard', 'Aws Io T Greengrass Component Public Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicCard
include('aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicCard('AwsIoTGreengrassComponentPublicCard', 'Aws Io T Greengrass Component Public Card', 'an optional description')
@enduml
```

## AwsIoTGreengrassComponentPublicGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicGroup
include('aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicGroup('AwsIoTGreengrassComponentPublicGroup', 'Aws Io T Greengrass Component Public Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicGroup
include('aws-q2-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicGroup('AwsIoTGreengrassComponentPublicGroup', 'Aws Io T Greengrass Component Public Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic.md <==
# AwsIoTGreengrassComponentPublic


```text
aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic
```

```text
include('aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')
```



| Illustration | AwsIoTGreengrassComponentPublic | AwsIoTGreengrassComponentPublicCard | AwsIoTGreengrassComponentPublicGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic.png) | ![illustration for AwsIoTGreengrassComponentPublic](../../../aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic.Local.png) | ![illustration for AwsIoTGreengrassComponentPublicCard](../../../aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublicCard.Local.png) | ![illustration for AwsIoTGreengrassComponentPublicGroup](../../../aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublicGroup.Local.png) |




## AwsIoTGreengrassComponentPublic

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublic
include('aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublic('AwsIoTGreengrassComponentPublic', 'Aws Io T Greengrass Component Public', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublic
include('aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublic('AwsIoTGreengrassComponentPublic', 'Aws Io T Greengrass Component Public', 'an optional tech label', 'an optional description')
@enduml
```

## AwsIoTGreengrassComponentPublicCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicCard
include('aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicCard('AwsIoTGreengrassComponentPublicCard', 'Aws Io T Greengrass Component Public Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicCard
include('aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicCard('AwsIoTGreengrassComponentPublicCard', 'Aws Io T Greengrass Component Public Card', 'an optional description')
@enduml
```

## AwsIoTGreengrassComponentPublicGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicGroup
include('aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicGroup('AwsIoTGreengrassComponentPublicGroup', 'Aws Io T Greengrass Component Public Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentPublicGroup
include('aws-q1-2022/Resource/LoT/AwsIoTGreengrassComponentPublic')

' renders the element
AwsIoTGreengrassComponentPublicGroup('AwsIoTGreengrassComponentPublicGroup', 'Aws Io T Greengrass Component Public Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
